==> hoc-1.24.0.tgz: package/lib/withStateValueTags.js <==
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import withStateValue from './withStateValue';

var withStateValueTags = function withStateValueTags(BaseComponent) {
  var displayName = BaseComponent.displayName;

  var BaseComponentWithState =
  /*#__PURE__*/
  function (_Component) {
    _inheritsLoose(BaseComponentWithState, _Component);

    function BaseComponentWithState() {
      var _this;

      for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
        args[_key] = arguments[_key];
      }

      _this = _Component.call.apply(_Component, [this].concat(args)) || this;
      _this.state = {
        tags: _this.props.tags || [] // valueInput

      };

      _this.onChangeTags = function (e, valuesToPropagate) {
        var _this$props = _this.props,
            onChangeTags = _this$props.onChangeTags,
            onChange = _this$props.onChange; // eslint-disable-line react/prop-types

        var tags = valuesToPropagate.tags;

        _this.setState({
          tags: tags
        }, function () {
          onChangeTags(e, valuesToPropagate);
          onChange(e, valuesToPropagate);
        });
      };

      _this.onChange = function (e, valuesToPropagate) {
        var onChange = _this.props.onChange;
        onChange(e, valuesToPropagate);
      };

      return _this;
    }

    var _proto = BaseComponentWithState.prototype;

    _proto.render = function render() {
      var tags = this.state.tags;
      var value = this.props.value;
      var onChangeTags = this.onChangeTags,
          onChange = this.onChange,
          props = this.props;
      return React.createElement("div", null, React.createElement(BaseComponent, Object.assign({}, props, {
        tags: tags,
        value: value,
        onChangeTags: onChangeTags,
        onChange: onChange
      })));
    };

    return BaseComponentWithState;
  }(Component);

  BaseComponentWithState.displayName = "withStateValueTags(" + displayName + ")";
  BaseComponentWithState.defaultProps = {
    onChange: function onChange() {},
    onChangeTags: function onChangeTags() {},
    value: ''
  };
  return withStateValue(BaseComponentWithState);
};

export default withStateValueTags;

==> hoc-1.25.0.tgz: package/lib/withStateValueTags.js <==
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import withStateValue from './withStateValue';

var withStateValueTags = function withStateValueTags(BaseComponent) {
  var displayName = BaseComponent.displayName;

  var BaseComponentWithState = /*#__PURE__*/function (_Component) {
    _inheritsLoose(BaseComponentWithState, _Component);

    function BaseComponentWithState() {
      var _this;

      for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
        args[_key] = arguments[_key];
      }

      _this = _Component.call.apply(_Component, [this].concat(args)) || this;
      _this.state = {
        tags: _this.props.tags || [] // valueInput

      };

      _this.onChangeTags = function (e, valuesToPropagate) {
        var _this$props = _this.props,
            onChangeTags = _this$props.onChangeTags,
            onChange = _this$props.onChange; // eslint-disable-line react/prop-types

        var tags = valuesToPropagate.tags;

        _this.setState({
          tags: tags
        }, function () {
          onChangeTags(e, valuesToPropagate);
          onChange(e, valuesToPropagate);
        });
      };

      _this.onChange = function (e, valuesToPropagate) {
        var onChange = _this.props.onChange;
        onChange(e, valuesToPropagate);
      };

      return _this;
    }

    var _proto = BaseComponentWithState.prototype;

    _proto.render = function render() {
      var tags = this.state.tags;
      var value = this.props.value;
      var onChangeTags = this.onChangeTags,
          onChange = this.onChange,
          props = this.props;
      return /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(BaseComponent, Object.assign({}, props, {
        tags: tags,
        value: value,
        onChangeTags: onChangeTags,
        onChange: onChange
      })));
    };

    return BaseComponentWithState;
  }(Component);

  BaseComponentWithState.displayName = "withStateValueTags(" + displayName + ")";
  BaseComponentWithState.defaultProps = {
    onChange: function onChange() {},
    onChangeTags: function onChangeTags() {},
    value: ''
  };
  return withStateValue(BaseComponentWithState);
};

export default withStateValueTags;
